@@ -21,14 +21,20 @@ ggtally <- function (G, p1, adj = 0, values = seq(-1, 1, by = 0.2), dotsize = 0.
         colnames(Zdf) <- c("PA1", "PA2")
         p1 <- p1 + geom_point(data = Zdf, aes(x = PA1, y = PA2), 
             size = dotsize, colour = dotcolour)
-        Zt <- Z[values >= 0, ]
-        Zt <- data.frame(Zt)
-        colnames(Zt) <- c("PA1", "PA2")
-        p1 <- p1 + geom_path(data = Zt, aes(x = PA1, y = PA2), colour = "blue", linewidth = 0.25)
-        Zt <- Z[values <= 0, ]
-        Zt <- data.frame(Zt)
-        colnames(Zt) <- c("PA1", "PA2")
-        p1 <- p1 + geom_path(data = Zt, aes(x = PA1, y = PA2), colour = "red", linewidth = 0.25)
+
+        if(sum(values >=0 ) > 1) { # only operate with two or more points.
+          Zt <- Z[values >= 0, ]
+          Zt <- data.frame(Zt)
+          colnames(Zt) <- c("PA1", "PA2")
+          p1 <- p1 + geom_path(data = Zt, aes(x = PA1, y = PA2), colour = "blue", linewidth = 0.25)
+	}
+
+        if(sum(values <=0 ) > 1) { # only operate with two or more points.
+          Zt <- Z[values <= 0, ]
+          Zt <- data.frame(Zt)
+          colnames(Zt) <- c("PA1", "PA2")
+          p1 <- p1 + geom_path(data = Zt, aes(x = PA1, y = PA2), colour = "red", linewidth = 0.25)
+        }
     }
     return(p1)
 }
